@@ -41,6 +41,14 @@ public enum PGProperty {
     DriverInfo.DRIVER_NAME,
     "Name of the Application (backend >= 9.0)"),
 
+  /**
+   * Assume the server is at least that version.
+   */
+  ASSUME_MIN_SERVER_VERSION(
+    "assumeMinServerVersion",
+    null,
+    "Assume the server is at least that version"),
+
   /**
    * Specifies what the driver should do if a query fails. In {@code autosave=always} mode, JDBC driver sets a savepoint before each query,
    * and rolls back to that savepoint in case of failure. In {@code autosave=never} mode (default), no savepoint dance is made ever.
@@ -57,15 +65,6 @@ public enum PGProperty {
     false,
     new String[] {"always", "never", "conservative"}),
 
-  /**
-   * Assume the server is at least that version.
-   */
-  ASSUME_MIN_SERVER_VERSION(
-    "assumeMinServerVersion",
-    null,
-    "Assume the server is at least that version"),
-
-
   /**
    * Use binary format for sending and receiving data if possible.
    */
@@ -583,6 +582,7 @@ public enum PGProperty {
     null,
     "The password for the client's ssl key (ignored if sslpasswordcallback is set)"),
 
+
   /**
    * The classname instantiating {@code javax.security.auth.callback.CallbackHandler} to use.
    */
@@ -626,7 +626,7 @@ public enum PGProperty {
     "any",
     "Specifies what kind of server to connect",
     false,
-    new String[] {"any", "master", "slave", "secondary",  "preferSlave", "preferSecondary"}),
+    new String [] {"any", "primary", "master", "slave", "secondary",  "preferSlave", "preferSecondary"}),
 
   /**
    * Enable or disable TCP keep-alive. The default is {@code false}.
